==> CGAL-5.6.1-doc_html.tar.xz: doc_html/Point_set_2/group__PkgPointSet2Ref.js <==
var group__PkgPointSet2Ref =
[
    [ "Concepts", "group__PkgPointSet2Concepts.html", "group__PkgPointSet2Concepts" ],
    [ "Range Search", "group__PkgPointSet2RangeSearch.html", "group__PkgPointSet2RangeSearch" ],
    [ "Nearest Neighbor Search", "group__PkgPointSet2NeighborSearch.html", "group__PkgPointSet2NeighborSearch" ],
    [ "Point_set_2", "classCGAL_1_1Point__set__2.html", [
      [ "Circle", "classCGAL_1_1Point__set__2.html#a45a82bc3a5bf910927de82d36cec5a5b", null ],
      [ "Edge", "classCGAL_1_1Point__set__2.html#ac8dc06a7e8ed84db602039dcac1682a4", null ],
      [ "Numb_type", "classCGAL_1_1Point__set__2.html#a9258923c736830e24b5ee5fb7377b0e1", null ],
      [ "Point", "classCGAL_1_1Point__set__2.html#a47c2fae327694e8864fec11db2bbd931", null ],
      [ "Segment", "classCGAL_1_1Point__set__2.html#a946c6b002232a7547c84f4270e0a2c4d", null ],
      [ "size_type", "classCGAL_1_1Point__set__2.html#a2d7ecd1c2015c634dfc41237b78b3a9c", null ],
      [ "Triangulation", "classCGAL_1_1Point__set__2.html#a2b29b78ad9c89e7365cd4c11d1f60ad6", null ],
      [ "Vertex", "classCGAL_1_1Point__set__2.html#afb4c49ad30bac36604b759755883ddfc", null ],
      [ "Vertex_handle", "classCGAL_1_1Point__set__2.html#a5ebf4f92a1c799aa8e0401fefefe647d", null ],
      [ "Point_set_2", "classCGAL_1_1Point__set__2.html#a76ffe85b529b264c2180f6ed9f5eaaa3", null ],
      [ "Point_set_2", "classCGAL_1_1Point__set__2.html#af4fe3cab515d97722194692975600cc9", null ],
      [ "lookup", "classCGAL_1_1Point__set__2.html#ae2b5169453797857710b5fb8f3705151", null ],
      [ "nearest_neighbor", "classCGAL_1_1Point__set__2.html#a32bb7adb34a460bf49be053393c28b72", null ],
      [ "nearest_neighbor", "classCGAL_1_1Point__set__2.html#a5c3cc0205f859e1d95bdb8dd2fcb59da", null ],
      [ "nearest_neighbors", "classCGAL_1_1Point__set__2.html#a56335e1ea6e4f69f917a2a16c442c98c", null ],
      [ "nearest_neighbors", "classCGAL_1_1Point__set__2.html#ac018fd40f089cd184ab577da908ae8f0", null ],
      [ "range_search", "classCGAL_1_1Point__set__2.html#afead91452fd7611ffe9529cdd09f20bd", null ],
      [ "range_search", "classCGAL_1_1Point__set__2.html#acbd435b2bfa63528fd8d25f61652e3d3", null ],
      [ "range_search", "classCGAL_1_1Point__set__2.html#a6c06c1cd9845414429cc37fe0438e942", null ]
    ] ]
];

==> CGAL-6.1-doc_html.tar.xz: doc_html/Point_set_2/group__PkgPointSet2Ref.js <==
var group__PkgPointSet2Ref =
[
    [ "Concepts", "group__PkgPointSet2Concepts.html", "group__PkgPointSet2Concepts" ],
    [ "Range Search", "group__PkgPointSet2RangeSearch.html", "group__PkgPointSet2RangeSearch" ],
    [ "Nearest Neighbor Search", "group__PkgPointSet2NeighborSearch.html", "group__PkgPointSet2NeighborSearch" ],
    [ "CGAL::Point_set_2< Gt, Tds >", "classCGAL_1_1Point__set__2.html", [
      [ "Circle", "classCGAL_1_1Point__set__2.html#a45a82bc3a5bf910927de82d36cec5a5b", null ],
      [ "Edge", "classCGAL_1_1Point__set__2.html#ac8dc06a7e8ed84db602039dcac1682a4", null ],
      [ "Numb_type", "classCGAL_1_1Point__set__2.html#a9258923c736830e24b5ee5fb7377b0e1", null ],
      [ "Point", "classCGAL_1_1Point__set__2.html#a47c2fae327694e8864fec11db2bbd931", null ],
      [ "Segment", "classCGAL_1_1Point__set__2.html#a946c6b002232a7547c84f4270e0a2c4d", null ],
      [ "size_type", "classCGAL_1_1Point__set__2.html#a2d7ecd1c2015c634dfc41237b78b3a9c", null ],
      [ "Triangulation", "classCGAL_1_1Point__set__2.html#a2b29b78ad9c89e7365cd4c11d1f60ad6", null ],
      [ "Vertex", "classCGAL_1_1Point__set__2.html#afb4c49ad30bac36604b759755883ddfc", null ],
      [ "Vertex_handle", "classCGAL_1_1Point__set__2.html#a5ebf4f92a1c799aa8e0401fefefe647d", null ],
      [ "Point_set_2", "classCGAL_1_1Point__set__2.html#a76ffe85b529b264c2180f6ed9f5eaaa3", null ],
      [ "Point_set_2", "classCGAL_1_1Point__set__2.html#af4fe3cab515d97722194692975600cc9", null ],
      [ "lookup", "classCGAL_1_1Point__set__2.html#ae2b5169453797857710b5fb8f3705151", null ],
      [ "nearest_neighbor", "classCGAL_1_1Point__set__2.html#a32bb7adb34a460bf49be053393c28b72", null ],
      [ "nearest_neighbor", "classCGAL_1_1Point__set__2.html#a5c3cc0205f859e1d95bdb8dd2fcb59da", null ],
      [ "nearest_neighbors", "classCGAL_1_1Point__set__2.html#a56335e1ea6e4f69f917a2a16c442c98c", null ],
      [ "nearest_neighbors", "classCGAL_1_1Point__set__2.html#ac018fd40f089cd184ab577da908ae8f0", null ],
      [ "range_search", "classCGAL_1_1Point__set__2.html#afead91452fd7611ffe9529cdd09f20bd", null ],
      [ "range_search", "classCGAL_1_1Point__set__2.html#acbd435b2bfa63528fd8d25f61652e3d3", null ],
      [ "range_search", "classCGAL_1_1Point__set__2.html#a6c06c1cd9845414429cc37fe0438e942", null ]
    ] ]
];
